/***************************************************************************
                          my_test.c  -  description
                             -------------------
    copyright            : (C) MySQL AB 1995-2002, www.mysql.com
 ***************************************************************************/
#include "mytest3.h"

/********************************************************
* main routine                                          *
*********************************************************/
#define MAX_SQL 	(1024)
#define STR_LEN 	(255)

#define WAIT_VALUE 	(60)
#define STEP_REPEAT	(2)

/* #define DSN_STR 	"DSN=%s; UID=%s; PWD=%s;" */
/* #define DSN_STR 	"DRIVER={MySQL ODBC 3.51Driver};SERVER=localhost;DATABASE=test; DSN=%s; UID=%s; PWD=%s; OPTION=3;"*/

#define DSN_STR 	"DRIVER={MySQL ODBC 3.51Driver}; DSN=%s; UID=%s; PWD=%s; OPTION=3;"
#define DBS_USE		"use test"
#define TABLE_NAME 	"tst5173"
#define CREATE_TAB	"create table %s (ch1 char(255))"
#define SELECT_TAB	"select ch1=? from %s"
#define DROP_TAB	"drop table %s"

int main(int argc, char *argv[])
{
  SQLHENV    henv;
  SQLHDBC    hdbc;
  SQLHSTMT   hstmt;
  SQLHWND 	 hwnd;
  SQLRETURN  rc;

  SQLCHAR    server_name[30];
  SQLCHAR    str_dsn[255];
  SQLCHAR    str_sql[MAX_SQL];
  SQLCHAR    szStr[STR_LEN];
  SQLINTEGER cbStr = SQL_NTS;
  SQLINTEGER cbConnStrOut=0;
  SQLINTEGER narg, i, j=0;

  time_t    time_b, time_e;

 /* ----------------------------------------------------------------------- */
    /*
     * if connection string supplied through arguments, overrite
     * the default one..
    */
    for(narg = 1; narg < argc; narg++)
    {
      if ( narg == 1 )
        mydsn = argv[1];
      else if ( narg == 2 )
        myuid = argv[2];
      else if ( narg == 3 )
        mypwd = argv[3];
    }
 /* ----------------------------------------------------------------------- */
 	/* --- alloc env handle --- */
    rc = SQLAllocHandle(SQL_HANDLE_ENV,SQL_NULL_HANDLE,&henv);
    myenv(henv, rc);
    printf("\n allocating environment handle ... success");

 	/* --- set odbc version --- */
    rc = SQLSetEnvAttr(henv,SQL_ATTR_ODBC_VERSION,(SQLPOINTER)SQL_OV_ODBC3,0);
    myenv(henv, rc);
    printf("\n setting the environment version ... success");

 	/* --- alloc dbc handle --- */
    rc = SQLAllocHandle(SQL_HANDLE_DBC,henv, &hdbc);
    myenv(henv, rc);
    printf("\n allocating the connection handle ...success");

	/* --- connect to server --- * /
    rc = SQLConnect(hdbc, mydsn, SQL_NTS, myuid, SQL_NTS,  mypwd, SQL_NTS); */
    mycon(hdbc, rc);
    printf("\n connecting to server using DSN '%s'... success",mydsn);

 /* ----------------------------------------------------------------------- */
    /* --- testing begin --- */
	sprintf(str_dsn, DSN_STR, mydsn, myuid, mypwd);

	rc = SQLDriverConnect(hdbc, NULL,
						  str_dsn, SQL_NTS,
						  "", 255,
						  &cbConnStrOut,
						  SQL_DRIVER_NOPROMPT);
    mycon(hdbc, rc);
    printf("\n dsn : %s ",str_dsn);
    printf("\n connecting to server using DSN '%s'... success (step 1.)",mydsn);

	/* --- getinfo DBMS name from driver --- */
    rc = SQLGetInfo(hdbc,SQL_DBMS_NAME,&server_name,40,NULL);
    mycon(hdbc, rc);
    printf("\n connection established successfully to server '%s'\n",server_name);

 	/* --- alloc stmt handle --- */
    rc = SQLAllocHandle(SQL_HANDLE_STMT,hdbc, &hstmt);
    mystmt(hstmt, rc);
    printf("\n allocating the statement handle ... success");

	/* --- execute select database --- */
	sprintf(str_sql, DBS_USE);
    rc = SQLExecDirect(hstmt, str_sql, SQL_NTS);
    mystmt(hstmt,rc);
    printf("\n select database ... success");

	/* --- execute create table --- */
	sprintf(str_sql, CREATE_TAB, TABLE_NAME);
    rc = SQLExecDirect(hstmt, str_sql, SQL_NTS);
    mystmt(hstmt,rc);
    printf("\n create table %s ... success", TABLE_NAME);

	/* --- repeat steps 2-4 --- */
	for (i=0; i < STEP_REPEAT; i++) {

	    /* --- wait to repeat steps ---*/
	    if (i > 0) {
		    printf("\n waiting (%d sec.) to repeat steps 2-4 ", WAIT_VALUE);
			time(&time_b);
			while(1) {
				time(&time_e);
				if ((time_e - time_b) >= WAIT_VALUE) break;
			} /* while ()*/
		} /* if () */

		/* --- bind parameter --- */
		rc = SQLBindParameter(hstmt, 1,
						  SQL_PARAM_INPUT,
						  SQL_C_CHAR,
						  SQL_CHAR,
						  STR_LEN, 0,
						  szStr, 0,
						  &cbStr);
	    mystmt(hstmt,rc);
	    printf("\n binding parameter ... success (step 2.)");

		/* --- execute statement --- */
		sprintf(str_sql, SELECT_TAB, TABLE_NAME);
	    rc = SQLExecDirect(hstmt, str_sql, SQL_NTS);
	    mystmt(hstmt,rc);
	    printf("\n select table %s ... success (step 3.)", TABLE_NAME);

		/* --- close cursor --- */
		rc = SQLCloseCursor(hstmt);
	    mystmt(hstmt,rc);
	    printf("\n closing cursor ... success (step 4.1.)");

		/* --- reset stmt handle --- */
		SQLFreeStmt(hstmt, SQL_RESET_PARAMS);
		mystmt(hstmt,rc);
	    printf("\n reset the statement handle ... success (step 4.2.)");
	}	/* for() */

	/* --- execute drop table --- */
	sprintf(str_sql, DROP_TAB, TABLE_NAME);
    rc = SQLExecDirect(hstmt, str_sql, SQL_NTS);
    mystmt(hstmt,rc);
    printf("\n drop table %s ... success", TABLE_NAME);

	/* --- free stmt handle --- */
    rc = SQLFreeHandle(SQL_HANDLE_STMT, hstmt);
    mystmt(hstmt, rc);
    printf("\n freeing the statement handle ... success");

    /* --- testing end --- */
 /* ----------------------------------------------------------------------- */
	/* --- disconnect to server --- */
    rc = SQLDisconnect(hdbc);
    mycon(hdbc, rc);
    printf("\n\n disconnecting to server ... success");

 	/* --- free dbc handle --- */
    rc = SQLFreeHandle(SQL_HANDLE_DBC, hdbc);
    mycon(hdbc, rc);
    printf("\n freeing the connecting handle ... success");

 	/* --- free env handle --- */
    rc = SQLFreeHandle(SQL_HANDLE_ENV, henv);
    myenv(henv, rc);
    printf("\n freeing the environment handle ... success");

  printf("\n\nSUCCESS ...\n\n");

  return(0);
}
